@@ -126,6 +126,26 @@ def location(x):
         b = point(*long_lat)
     return b
 
+def _length(x):
+    """
+    Lenght between two points
+
+    :param x: Two points
+    :type x: list
+    :rtype: float
+
+    >>> from text_models.place import _length
+    >>> points = [[-103.7420245057158, 17.915988111000047], [-100.1228494938091, 20.403147690813284]]
+    >>> _length(points)
+    470.06161477088165
+
+    """
+
+    points = [point(*_) for _ in x]
+    uno = points[0]
+    dos = points[1]
+    return distance(uno[0], uno[1], dos[0], dos[1])
+
 
 def length(x):
     """
@@ -146,11 +166,8 @@ def length(x):
         return 0
 
     place = x["place"]
-    bbox = place.get("bounding_box", dict()).get("coordinates")
-    bbox = np.array([point(*x) for x in bbox[0]])
-    uno = bbox[0]
-    dos = bbox[2]
-    return distance(uno[0], uno[1], dos[0], dos[1])
+    bbox = place.get("bounding_box", dict()).get("coordinates")[0]
+    return _length([bbox[0], bbox[2]])
 
 
 class CP(object):
@@ -471,7 +488,10 @@ class Mobility(object):
         weekday_data = self.group_by_weekday(data)
         output = dict()
         for key, data in weekday_data.items():
-            output[key] = MobilityTransform({k: np.median(v) for k, v in data.items()})
+            _ = {k: np.median(v) for k, v in data.items()}
+            if sum([1 for v in _.values() if v != 0]) < len(data):
+                continue 
+            output[key] = MobilityTransform(_)
         return output
 
     def weekday_probability(self, data):
@@ -510,7 +530,7 @@ class Mobility(object):
         """
 
         for v in baseline.values():
-            v.travel_instance = self
+            v.mobility_instance = self
         return self._apply(data, baseline)
 
     @staticmethod
@@ -522,7 +542,7 @@ class Mobility(object):
         :type func: dict
         """
 
-        return {k: func[k].transform(v) for k, v in data.items()}
+        return {k: func[k].transform(v) for k, v in data.items() if k in func}
 
 Travel = Mobility
 
@@ -590,6 +610,7 @@ class BoundingBox(object):
         return self.pc[label]
 
     def label(self, data):
+
         """
         The label of the closest bounding-box centroid to the data
 
@@ -617,4 +638,46 @@ class BoundingBox(object):
                 acl = "%s:%s" % (country, acl)            
             return acl
         except KeyError:
-            return country
\ No newline at end of file
+            return country
+
+
+class States(object):
+    def __init__(self):
+        from cartopy.io import shapereader
+        fname = shapereader.natural_earth(resolution='10m',
+                                          category='cultural',
+                                          name='admin_1_states_provinces')
+        _ = shapereader.Reader(fname)
+        self._records = {x.attributes["iso_3166_2"]: x for x in _.records()}
+
+    def associate(self, data, country=None):
+        """
+        Associate a array of points with the states. 
+
+        :param data: Array of points in radians (lat, lon)
+        :type data: list
+        :param country: Country using two letters code
+        :type country: str
+
+        """
+        from shapely.geometry import Point
+        records = self._records
+        data = np.rad2deg(data)
+        data = data[:, ::-1]
+        data = [[k, Point(a, b)] for k, (a, b) in enumerate(data)]
+        country = country.upper()
+        keys = {k for k in records.keys() if k[:2] == country}
+        output = []
+        for k in keys:
+            if len(data) == 0:
+                break
+            d = records[k].geometry
+            res = [[i, d.contains(x)] for i, x in data]
+            output.extend([[i, k] for i, flag in res if flag])
+            data = [d for d, (_, flag) in zip(data, res) if not flag]
+        for i, point in data:
+            _ = [[k, records[k].geometry.distance(point)] for k in keys]
+            _.sort(key=lambda x: x[1])
+            output.append([i, _[0][0]])
+        output.sort(key=lambda x: x[0])
+        return [o for _, o in output]
