@@ -184,7 +184,7 @@ def test_travel_weekday_percentage():
         print(_)
         assert _._data[wk] > 0
     for v in baseline.values():
-        v.travel_instance = travel
+        v.mobility_instance = travel
     y = baseline["MX"].transform(inside["MX"])
     assert len(y) == len(travel.dates)
 
@@ -203,6 +203,16 @@ def test_travel_percentage_by_weekday():
         assert len([1 for x in v if x == 0]) == 7
 
 
+def test_travel_percentage_by_weekday2():
+    from text_models.place import Travel
+    import numpy as np
+    travel = Travel(window=21)
+    inside = travel.inside_mobility(travel.bounding_box.city)
+    baseline = travel.weekday_percentage(inside)
+    print(len(baseline))
+    assert len(baseline) < 14347 
+
+
 def test_travel_weekday_probability():
     from text_models.utils import Gaussian
     from text_models.place import Travel
@@ -226,3 +236,19 @@ def test_gaussian():
     _ = g.predict_proba([0.1, 0.4, 0.41, 0.5, 10., -10])
     assert np.all(_[-2:] < 1e-6)
     assert np.all(_[:-2] > 0)
+
+
+def test_states():
+    from text_models.place import States, BoundingBox
+
+    bbox = BoundingBox()
+    states = States()
+    data = bbox.bounding_box["MX"]
+    res = states.associate(data, country="MX")
+    assert len(res) == data.shape[0]
+    ags = [[k, x] for k, x in enumerate(res) if x == "MX-AGU"]
+    for k, _ in ags:
+        key = "MX:%s" % k
+        postal_code = bbox.postal_code(key)
+        print(postal_code, k)
+        assert bbox._postal_code_names[postal_code][0] == "01"
